Learn R Programming

flowCHIC (version 1.6.0)

Results_overlaps: Dataset with labels and sums of informative pixels within the overlap area of the FCS files included to the package

Description

Example dataset containing labels and areas of each image pair of the FCS files included to the package.

Usage

data(Results_overlaps)

Arguments

Value

calculate_overlaps_xor() on the FCS files included to the package.

Format

Data frame with 3 observations of 2 variables.