Learn R Programming

flowCHIC (version 1.6.0)

Results_overlaps_incol: Dataset with labels and sums of informative pixels within the overlap area of the second downloadable dataset

Description

Example dataset containing labels and areas of each image pair of the second downloadable dataset (see manual).

Usage

data(Results_overlaps_incol)

Arguments

Value

calculate_overlaps_xor() on the subsets of the second downloadable dataset.

Format

Data frame with 136 observations of 2 variables.