Results_overlaps_mix: Dataset with labels and sums of informative pixels within the overlap area of the first downloadable dataset
Description
Example dataset containing labels and areas of each image pair of the first downloadable dataset (see manual).Usage
data(Results_overlaps_mix)
Value
calculate_overlaps_xor() on the subsets of the first downloadable dataset.
Format
Data frame with 4005 observations of 2 variables.