Results_xor: Dataset with labels and intensity values of the FCS files included to the package
Description
Example dataset containing labels and intensity values of each image pair of the FCS files included to the package.Value
calculate_overlaps_xor() on the FCS files included to the package.
Format
Data frame with 3 observations of 2 variables.