Results_xor_incol: Dataset with labels and intensity values of the second downloadable dataset
Description
Example dataset containing labels and intensity values of each image pair of the second downloadable dataset (see manual).Usage
data(Results_xor_incol)
Value
calculate_overlaps_xor() on the subsets of the second downloadable dataset.
Format
Data frame with 136 observations of 2 variables.