Learn R Programming

flowCHIC (version 1.6.0)

Results_xor_mix: Dataset with labels and intensity values of the first downloadable dataset

Description

Example dataset containing labels and intensity values of each image pair of the first downloadable dataset (see manual).

Usage

data(Results_xor_mix)

Arguments

Value

calculate_overlaps_xor() on the subsets of the first downloadable dataset.

Format

Data frame with 4005 observations of 2 variables.